@@ -18,16 +18,7 @@ def get_principal_values(tensors):
 
     """
 
-    eigvals = np.linalg.eigvals(tensors)
-
-    # sort_idx = np.argsort(np.abs(eigvals), axis=-1)
-    # out = np.take_along_axis(eigvals, sort_idx, axis=-1)[..., ::-1]
-
-    out = np.sort(eigvals, axis=-1)[..., ::-1]
-
-    # out = eigvals
-
-    return out
+    return np.sort(np.linalg.eigvals(tensors), axis=-1)[..., ::-1]
 
 
 def get_plane_coords(a, b, c, side_length, resolution, up=None):
